<?php
/**
 * Copyright (C) 2014-2017 ServMask Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ███████╗███████╗██████╗ ██╗   ██╗███╗   ███╗ █████╗ ███████╗██╗  ██╗
 * ██╔════╝██╔════╝██╔══██╗██║   ██║████╗ ████║██╔══██╗██╔════╝██║ ██╔╝
 * ███████╗█████╗  ██████╔╝██║   ██║██╔████╔██║███████║███████╗█████╔╝
 * ╚════██║██╔══╝  ██╔══██╗╚██╗ ██╔╝██║╚██╔╝██║██╔══██║╚════██║██╔═██╗
 * ███████║███████╗██║  ██║ ╚████╔╝ ██║ ╚═╝ ██║██║  ██║███████║██║  ██╗
 * ╚══════╝╚══════╝╚═╝  ╚═╝  ╚═══╝  ╚═╝     ╚═╝╚═╝  ╚═╝╚══════╝╚═╝  ╚═╝
 */

class Ai1wmoe_Import_Controller {

	public static function button() {
		return Ai1wm_Template::get_content(
			'import/button',
			array( 'token' => get_option( 'ai1wmoe_onedrive_token' ) ),
			AI1WMOE_TEMPLATES_PATH
		);
	}

	public static function picker() {
		Ai1wm_Template::render(
			'import/picker',
			array(),
			AI1WMOE_TEMPLATES_PATH
		);
	}

	public static function folder() {
		try {
			$client = new ServMaskOneDriveClient(
				get_option( 'ai1wmoe_onedrive_token' ),
				get_option( 'ai1wmoe_onedrive_ssl', true )
			);

			$response = array();

			$path = null;
			if ( isset( $_GET['path'] ) && ( $_GET['path'] === '/' ) ) {
				$path = '';
			} elseif ( isset( $_GET['path'] ) ) {
				$path = trim( $_GET['path'] );
			}

			// Get files and directories
			if ( $path ) {
				$items = $client->listFolder( $path );
			} else {
				$items = $client->listDrive();
			}

			// Set folder structure
			$response = array( 'items' => array() );

			// Prepare items
			if ( isset( $items['value'] ) && ( $entries = $items['value'] )  ) {
				// Sort entries by date desc
				usort( $entries, 'self::sort_by_date_desc' );

				// Loop over entries
				foreach ( $entries as $entry ) {
					$response['items'][] = array(
						'name'  => isset( $entry['name'] ) ? $entry['name'] : null,
						'date'  => isset( $entry['createdDateTime'] ) ? human_time_diff( strtotime( $entry['createdDateTime'] ) ) : null,
						'size'  => isset( $entry['size'] ) ? size_format( $entry['size'] ) : null,
						'bytes' => isset( $entry['size'] ) ? $entry['size'] : null,
						'path'	=> isset( $entry['parentReference']['path'] ) ? str_replace( '/drive/root:/', '', sprintf( '%s/%s', $entry['parentReference']['path'], $entry['name'] ) ) : null,
						'type'  => isset( $entry['folder'] ) ? 'folder' : 'file',
					);
				}
			}

			echo json_encode( $response );
			exit;
		} catch ( Exception $e ) {
			status_header( $e->getCode() );
			echo json_encode( array( 'message' => $e->getMessage() ) );
			exit;
		}
	}

	public static function sort_by_date_desc( $first_backup, $second_backup ) {
		return strtotime( $second_backup['createdDateTime'] ) - strtotime( $first_backup['createdDateTime'] );
	}
}
