<?php
/**
 * Copyright (C) 2014-2017 ServMask Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ███████╗███████╗██████╗ ██╗   ██╗███╗   ███╗ █████╗ ███████╗██╗  ██╗
 * ██╔════╝██╔════╝██╔══██╗██║   ██║████╗ ████║██╔══██╗██╔════╝██║ ██╔╝
 * ███████╗█████╗  ██████╔╝██║   ██║██╔████╔██║███████║███████╗█████╔╝
 * ╚════██║██╔══╝  ██╔══██╗╚██╗ ██╔╝██║╚██╔╝██║██╔══██║╚════██║██╔═██╗
 * ███████║███████╗██║  ██║ ╚████╔╝ ██║ ╚═╝ ██║██║  ██║███████║██║  ██╗
 * ╚══════╝╚══════╝╚═╝  ╚═╝  ╚═══╝  ╚═╝     ╚═╝╚═╝  ╚═╝╚══════╝╚═╝  ╚═╝
 */

class Ai1wmoe_Settings_Controller {

	public static function index() {
		$model = new Ai1wmoe_Settings;

		$onedrive_backup_schedules = get_option( 'ai1wmoe_onedrive_cron', array() );
		$last_backup_timestamp     = get_option( 'ai1wmoe_onedrive_timestamp', false );

		$last_backup_date = $model->get_last_backup_date( $last_backup_timestamp );
		$next_backup_date = $model->get_next_backup_date( $onedrive_backup_schedules );

		Ai1wm_Template::render(
			'settings/index',
			array(
				'backups'                   => get_option( 'ai1wmoe_onedrive_backups', false ),
				'onedrive_backup_schedules' => $onedrive_backup_schedules,
				'email'                     => get_option( 'ai1wmoe_onedrive_notify_email', get_option( 'admin_email', '' ) ),
				'notify'                    => get_option( 'ai1wmoe_onedrive_notify_toggle', false ),
				'last_backup_date'          => $last_backup_date,
				'next_backup_date'          => $next_backup_date,
				'ssl'                       => get_option( 'ai1wmoe_onedrive_ssl', true ),
				'token'                     => get_option( 'ai1wmoe_onedrive_token', false ),
				'total'                     => get_option( 'ai1wmoe_onedrive_total', false ),
			),
			AI1WMOE_TEMPLATES_PATH
		);
	}

	public static function settings() {
		$params = stripslashes_deep( $_POST );

		// OneDrive update
		if ( isset( $params['ai1wmoe_onedrive_update'] ) ) {
			$model = new Ai1wmoe_Settings;

			// Cron update
			if ( ! empty( $params['ai1wmoe_onedrive_cron'] ) ) {
				$model->set_cron( (array) $params['ai1wmoe_onedrive_cron'] );
			} else {
				$model->set_cron( array() );
			}

			// Set SSL mode
			if ( ! empty( $params['ai1wmoe_onedrive_ssl'] ) ) {
				$model->set_ssl( 0 );
			} else {
				$model->set_ssl( 1 );
			}

			// Set number of backups
			if ( ! empty( $params['ai1wmoe_onedrive_backups'] ) ) {
				$model->set_backups( (int) $params['ai1wmoe_onedrive_backups'] );
			} else {
				$model->set_backups( 0 );
			}

			// Set size of backups
			if ( ! empty( $params['ai1wmoe_onedrive_total'] ) && ! empty( $params['ai1wmoe_onedrive_total_unit'] ) ) {
				$model->set_total( (int) $params['ai1wmoe_onedrive_total'] . trim( $params['ai1wmoe_onedrive_total_unit'] ) );
			} else {
				$model->set_total( 0 );
			}

			// Set notification toggle
			$model->set_toggle( isset( $params['ai1wmoe_notification_toggle'] ) );

			// Set notification email
			$model->set_email( $params['ai1wmoe_notification_email'] );
		}

		// Redirect to settings page
		wp_redirect( network_admin_url( 'admin.php?page=site-migration-onedrive-settings' ) );
		exit;
	}

	public static function revoke() {
		$params = stripslashes_deep( $_POST );

		// OneDrive logout
		if ( isset( $params['ai1wmoe_onedrive_logout'] ) ) {
			$model = new Ai1wmoe_Settings;
			$model->revoke();
		}

		// Redirect to settings page
		wp_redirect( network_admin_url( 'admin.php?page=site-migration-onedrive-settings' ) );
		exit;
	}

	public static function account() {
		try {
			// OneDrive account
			$model = new Ai1wmoe_Settings;
			if ( ( $account = $model->get_account() ) ) {
				echo json_encode( $account );
				exit;
			}
		} catch ( Exception $e ) {
			status_header( $e->getCode() );
			echo json_encode( array( 'message' => $e->getMessage() ) );
			exit;
		}
	}
}
