<?php
/**
 * Copyright (C) 2014-2017 ServMask Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ███████╗███████╗██████╗ ██╗   ██╗███╗   ███╗ █████╗ ███████╗██╗  ██╗
 * ██╔════╝██╔════╝██╔══██╗██║   ██║████╗ ████║██╔══██╗██╔════╝██║ ██╔╝
 * ███████╗█████╗  ██████╔╝██║   ██║██╔████╔██║███████║███████╗█████╔╝
 * ╚════██║██╔══╝  ██╔══██╗╚██╗ ██╔╝██║╚██╔╝██║██╔══██║╚════██║██╔═██╗
 * ███████║███████╗██║  ██║ ╚████╔╝ ██║ ╚═╝ ██║██║  ██║███████║██║  ██╗
 * ╚══════╝╚══════╝╚═╝  ╚═╝  ╚═══╝  ╚═╝     ╚═╝╚═╝  ╚═╝╚══════╝╚═╝  ╚═╝
 */

class Ai1wmoe_Settings {

	public function revoke() {
		// Remove token option
		delete_option( 'ai1wmoe_onedrive_token' );

		// Reset cron schedules
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_hourly_export' );
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_daily_export' );
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_weekly_export' );
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_monthly_export' );
	}

	public function get_last_backup_date( $last_backup_timestamp ) {
		if ( $last_backup_timestamp ) {
			$last_backup_date = get_date_from_gmt( date( 'Y-m-d H:i:s', $last_backup_timestamp ), 'F j, Y g:i a' );
		} else {
			$last_backup_date = __( 'None', AI1WMOE_PLUGIN_NAME );
		}

		return $last_backup_date;
	}

	public function get_next_backup_date( $schedules ) {
		$future_backup_timestamps = array();

		foreach ( $schedules as $schedule ) {
			$future_backup_timestamps[] = wp_next_scheduled( "ai1wmoe_onedrive_{$schedule}_export", array( array(
					'secret_key' => get_option( AI1WM_SECRET_KEY ),
					'onedrive'   => 1,
				),
			) );
		}

		sort( $future_backup_timestamps );

		if ( isset( $future_backup_timestamps[0] ) ) {
			$next_backup_date = get_date_from_gmt( date( 'Y-m-d H:i:s', $future_backup_timestamps[0] ), 'F j, Y g:i a' );
		} else {
			$next_backup_date = __( 'None', AI1WMOE_PLUGIN_NAME );
		}

		return $next_backup_date;
	}

	public function get_account( ServMaskOneDriveClient $onedrive = null ) {
		// Set OneDrive client
		if ( is_null( $onedrive ) ) {
			$onedrive = new ServMaskOneDriveClient(
				get_option( 'ai1wmoe_onedrive_token' ),
				get_option( 'ai1wmoe_onedrive_ssl', true )
			);
		}

		// Get user information
		$user = $onedrive->getUserInfo();

		// Set user email
		$email = null;
		if ( isset( $user['userPrincipalName'] ) ) {
			$email = $user['userPrincipalName'];
		}

		// Get account info
		$account = $onedrive->getAccountInfo();

		// Set account name
		$name = null;
		if ( isset( $account['owner']['user']['displayName'] ) ) {
			$name = $account['owner']['user']['displayName'];
		}

		// Set used quota
		$used = null;
		if ( isset( $account['quota']['used'] ) ) {
			$used = $account['quota']['used'];
		}

		// Set total quota
		$total = null;
		if ( isset( $account['quota']['total'] ) ) {
			$total = $account['quota']['total'];
		}

		return array(
			'name'     => $name,
			'email'    => $email,
			'used'     => size_format( $used ),
			'total'    => size_format( $total ),
			'progress' => ceil( ( $used / $total ) * 100 ),
		);
	}

	public function set_cron( $schedules ) {
		// Reset cron schedules
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_hourly_export' );
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_daily_export' );
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_weekly_export' );
		Ai1wm_Cron::clear( 'ai1wmoe_onedrive_monthly_export' );

		// Update cron options
		update_option( 'ai1wmoe_onedrive_cron', $schedules );

		// Update cron schedules
		foreach ( $schedules as $recurrence ) {
			Ai1wm_Cron::add( "ai1wmoe_onedrive_{$recurrence}_export", $recurrence, array(
				'secret_key' => get_option( AI1WM_SECRET_KEY ),
				'onedrive'   => 1,
			) );
		}
	}

	public function set_ssl( $mode ) {
		update_option( 'ai1wmoe_onedrive_ssl', $mode );
	}

	public function set_backups( $number ) {
		update_option( 'ai1wmoe_onedrive_backups', $number );
	}

	public function set_total( $size ) {
		update_option( 'ai1wmoe_onedrive_total', $size );
	}

	public function set_email( $email ) {
		update_option( 'ai1wmoe_onedrive_notify_email', $email );
	}

	public function set_toggle( $toggle ) {
		update_option( 'ai1wmoe_onedrive_notify_toggle', $toggle );
	}
}
